ircN for mIRC — File Browser

ircNformIRCv6.0 / ircNformIRCv6.0 / ircn / SYSTEM / Raw.mrc

Raw.mrc — 15.79 KB — Download this file

raw 1:* { halt }
raw 2:* { halt }
raw 3:* { halt }
raw 4:* { halt }
raw 203:* { halt }
raw 204:* {
  if (%rawcode.204 == off) { unset %rawcode.204 | halt }
  inc %trcnm
  if (%trcnm == 1) {
    window -a @Trace %tloc $tp(trace.txt) FixedSys 9
    write -c $tp(trace.txt)
    write $tp(trace.txt) exit $chr(123) set $chr(37) $+ tloc $chr(36) $+ swlc(@Trace) $chr(124) window -c @Trace $chr(125)
    write $tp(trace.txt) -
    aline @Trace . $+ $str(-,50) $+ .
    aline @Trace $chr(124) IRC Operators on $fix(31,$hc(%trcsvr)) $chr(124)
    aline @Trace $chr(124) $+ $str(-,50) $+ $chr(124)
    aline @Trace $chr(124) $str( ,3) Nick $str( ,11) Address $str( ,19) $chr(124)
  }
  aline @Trace $chr(124) $lfix(2,%trcnm) $+ . $fix(11,$token(1,91,$4)) $fix(32,$sc($remove($token(2,91,$4),]))) $chr(124)
  titlebar @Trace - %trcnm IRCops found on %trcsvr
  write $tp(trace.txt) $token(1,91,$4)
  write $tp(trace.txt) .who $chr(123) who $token(1,91,$4) $chr(125)
  write $tp(trace.txt) .ping $chr(123) ctcp $token(1,91,$4) ping $chr(125)
  write $tp(trace.txt) .query $chr(123) query $token(1,91,$4) $chr(125)
  write $tp(trace.txt) .finger $chr(123) finger $token(1,91,$4) $chr(125)
  write $tp(trace.txt) .whois $chr(123) whois $token(1,91,$4) $chr(125)
  write $tp(trace.txt) .version $chr(123) ctcp $token(1,91,$4) version $chr(125)
  halt
}
raw 206:* { halt }
raw 209:* { halt }
raw 211:* {
  if (%rawcode.211 == off) { unset %rawcode.211 | halt }
  if (%clientscan == on) {
    inc %clientnum
    write -c $tp(clientscan.txt)
    write $tp(clientscan.txt) exit $chr(123) set %csloc $chr(36) $+ swlc(@ClientScan) $chr(124) window -c @ClientScan $chr(125)
    window -a @ClientScan %csloc $tp(clientscan.txt) FixedSys 9
    if (%clientnum == 1) {
      aline @ClientScan . $+ $str(-,60) $+ .
      aline @ClientScan $chr(124) $center(58,Client Scan of [ $hc(%pserver) ] ) $chr(124)
      aline @ClientScan $chr(124) $+ $str(-,60) $+ $chr(124)
      aline @ClientScan $chr(124) $+ $chr(160) $+ $chr(160) $+ Nick $+ $str($chr(160),8) $+ Host $+ $str($chr(160),42) $+ $chr(124)
      aline @ClientScan $chr(124) $+ $str($chr(160),60) $+ $chr(124)
    }
    if ($left($2,$len(%pserver)) != %pserver) {
      if ((. !isin $left($2,$pos($2,[))) && ($remove($left($2,$pos($2,[)),[))) {
        aline @ClientScan $chr(124) $+ $chr(160) $+ $fix(10,$sc($left($2,$sub($pos($2,[),1))) $+ $str($chr(160),2)) $+ $fix(49,$replace($strip($remove($right($2,$sub($len($2),$pos($2,[))),])),@,10@)) $+ $chr(124)
      }
    }
    halt
  }
  elseif (%spoofchk.nick) {
    set %spoofchk.chkhost $gettok($gettok($2,2,41),1,93)
    set %spoofchk.chkip $gettok($gettok($2,2,64),1,93)
    .dns $gettok(%spoofchk.host,2,64)
    halt
  }
  elseif (%portscan == on) {
    set %port.n $remove($right($2,5),])
    if ((%port.n isnum) && ($left($2,$len(%pserver)) == %pserver)) {
      inc %portnum
      if (%portnum == 1) {
        window -ae @PortScan %ploc /server $tp(portscan.txt) FixedSys 9
        titlebar @PortScan - Scanning %pserver $+ ...
        aline @PortScan . $+ $str(-,40) $+ .
        aline @PortScan $chr(124) PortScan of $fix(26,$hc(%pserver)) $chr(124)
        aline @PortScan $chr(124) $+ $str(-,40) $+ $chr(124)
        aline @PortScan $chr(124) $str( ,8) Port $str( ,4) Lag $str( ,14) $chr(124)
        aline @PortScan $chr(124) $+ $str( ,40) $+ $chr(124)
        write -c $tp(portscan.txt)
        write $tp(portscan.txt) exit:/set $chr(37) $+ ploc $chr(36) $+ swlc(@PortScan) $chr(124) window -c @Portscan
        write $tp(portscan.txt) -
      }
      if (%port.o == $null) {
        set %port.o $pls($5,$7)
        set %port %port.n
        write $tp(portscan.txt) %port $+ :/server %pserver %port
        aline @PortScan $chr(124) $str( ,4)  $lfix(2,%portnum) $+ . $fix(9,%port) $fix(19,$sc(%port.o)) $chr(124)
        halt
      }
      set %port.l $pls($5,$7)
      if (%port.l < %port.o) {
        set %port.o %port.l
        set %port %port.n
      }
      write $tp(portscan.txt) %port.n $+ :/server %pserver %port.n
      aline @PortScan $chr(124) $str( ,4)  $lfix(2,%portnum) $+ . $fix(9,%port.n) $fix(19,$sc(%port.l)) $chr(124)
    }
    else {
      if (%pserver isin $2) {
        inc %portnum
        if (%portnum == 1) {
          window -ae @PortScan %ploc /server $tp(portscan.txt) FixedSys 9
          aline @PortScan . $+ $str(-,40) $+ .
          aline @PortScan $chr(124) PortScan of $fix(26,$hc(%pserver)) $chr(124)
          aline @PortScan $chr(124) $+ $str(-,40) $+ $chr(124)
          aline @PortScan $chr(124)          Port       Lag $str( ,14) $chr(124)
          aline @PortScan $chr(124) $+ $str( ,40) $+ $chr(124)
          write -c $tp(portscan.txt)
          write $tp(portscan.txt) exit:/set $chr(37) $+ ploc $chr(36) $+ swlc(@PortScan) $chr(124) window -c @Portscan
          write $tp(portscan.txt) -
        }
        if (%port.o == $null) {
          set %port.o $pls($5,$7)
          set %port default
          write $tp(portscan.txt) default:/server %pserver
          aline @PortScan $chr(124) $str( ,4) $lfix(2,%portnum) $+ . $fix(9,default) $fix(19,$sc(%port.o)) $chr(124)
          halt
        }
        set %port.l $pls($parm5,$parm7)
        if (%port.l < %port.o) {
          set %port.o %port.l
          set %port default
          halt
        }
        write $tp(portscan.txt) default:/server %pserver
        aline @PortScan $chr(124) $str( ,4) $lfix(2,%portnum) $+ . $fix(9,default) $fix(19,$sc(%port.l)) $chr(124)
      }
      else halt
    }
  }
  if (%portscan == on) halt
}
raw 219:* {
  if (%rawcode.219 == off) { unset %rawcode.219 | halt }
  if (%spoofchk.nick) {
    if (%spoofchk.chkip) { halt }
    else {
      if ($form(errors,checkhost)) iecho $readini %formats errors checkhost
      else iecho Could not check %spoofchk.nick for a spoofed address.
      unset %spoofchk*
      halt
    }
  }
  elseif (%spoofchk.nick) { halt }
  elseif (%clientscan == on) {
    unset %clientscan %clientnum %pserver
    aline @ClientScan · $+ $str(-,60) $+ ·
    halt
  }
  elseif (%portscan == on) {
    if ((%port == $null) || (%portnum == 0)) {
      if ($form(errors,portscan)) iecho $readini %formats errors portscan
      else iecho Unable to locate port information for $hc(%pserver) $+ .
      unset %port* %pserver
      halt
    }
    elseif (%port == default) {
      titlebar @PortScan - Best port: default
      aline @Portscan $chr(124) $+ $str(-,40) $+ $chr(124)
      aline @PortScan $chr(124) Best available port is server default  $chr(124)
      aline @PortScan $chr(124) To join server/port press $hc(F12) $str( ,8) $chr(124)
      set %kchan server %pserver
    }
    elseif ($server != %pserver) {
      titlebar @PortScan - Best port: %port
      aline @Portscan $chr(124) $+ $str(-,40) $+ $chr(124)
      aline @PortScan $chr(124) Best available port is $fix(15,$hc(%port)) $chr(124)
      aline @PortScan $chr(124) To join server/port press $hc(F12) $str( ,8) $chr(124)
      set %kchan server %pserver %port
    }
    elseif ((%port == $port) && ($server == %pserver)) {
      titlebar @PortScan - Best port: current
      aline @Portscan $chr(124) $+ $str(-,40) $+ $chr(124)
      aline @PortScan $chr(124)   You are on the best available port   $chr(124)
    }
    else {
      titlebar @PortScan - Best port: %port
      aline @Portscan $chr(124) $+ $str(-,40) $+ $chr(124)
      aline @PortScan $chr(124) Best available port is $fix(15,$hc(%port)) $chr(124)
      aline @PortScan $chr(124) To join server/port press $hc(F12) $str( ,8) $chr(124)
      set %kchan server %pserver %port
    }
    aline @PortScan ' $+ $str(-,40) $+ '
    unset %port* %pserver
    halt
  }
}
raw 250:* {
  if (%rawcode.250 == off) { unset %rawcode.250 | halt }
  echo -s $str( ,5) $chr(124) $+ $str( ,51) $+ $chr(124)
  echo -s $str( ,5) $chr(124) $+ $str( ,51) $+ $chr(124)
  echo -s $str( ,5) $chr(124) $+ $ocenter(50,Type /help for help.) $chr(124)
  echo -s $str( ,5) $chr(124) $+ $str( ,51) $+ $chr(124)
  echo -s $str( ,5) ' $+ $str(-,51) $+ '
  echo -s 14BitchX 74p3 by zerosouls for mirc ..(loaded)..
  echo -s 14Keep it to yourself beotch!@^&$%
  halt
}
raw 251:* {
  if (%rawcode.251 == off) { unset %rawcode.251 | halt }
  set %tmp1 $readini $sys(mirc.ini) colours n0
  if ($left(%tmp1,1) == 0) { set %tmp 00 | set %tmp2 1 }
  elseif ($left(%tmp1,1) == 1) { set %tmp 01 | set %tmp2 00 }
  else { set %tmp $left(%tmp1,1) | set %tmp2 01 }
  echo -2 1kkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk
  echo -2 14------------------------------------------------------------------------
  echo -2 1kkkkk15____,--,____1kkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk
  echo -2 1kkkk15(1kkkkkkkkkkkk15)_____,`',___1k15_,,.__1k15__,.__1k15___1kkkkk15___1k15__________
  echo -2 1kkkkk15|1kkkk15______|_1kkkkkkkkkkkk15)1kkkkkk15)1kkkkkk15(1kkk15`-.-'1kkk15)1kkkkkkkkkk15)
  echo -2 1kkkkk15\______1kkkkkk)1kkkkkkkkkk|1kkkkkk|1kkkkkk|1kkkkkkkkkkk|1kkkkkk____|
  echo -2 1kkkk(1kkkkk|1kkkkkk|1kkkkkk|1kkkk|1kkkkkk|1kkkkkk.'1kkkk|1kkkkk|1kkkk____)
  echo -2 1kkkkk|1kkkk|1kkkkkk|1kkk|__|1kkkk|1kkkkkk:1kkkkkk|1kkkkk|_1kk__)1kkkkkk|
  echo -2 1kkkk(__1kkkkkkkkkk_)1kk|1kk|___1k:1kkkkkk.1kkkkkk|1kkkkk|1k`-'1k|1kkkkkk|
  echo -2 1kkkkkkk`|1kkkkkkk|1kk:1k:1kkkkkk|;1kkkkkkkkkkkkk|1kkkkk|1kkkkk|1kkkkkk:
  echo -2 1kkkkkkkk:1kkkkkkk;1kk`1k;1kkkkkkk'1kkkkkkkkkkkkkkkkkkk|1kkkkk:1kkkkkk'
  echo -2 1kkkkkkkk`1kkkkkkkkkkkkkkkkki1kkkkkkkr1kkkkkkc1kkkkkkk:1kkkkk:quix!
  echo -2 1kkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk'1kkkkk`
  echo -2 14------------------------------------------------------------------------
  unset %tmp %tmp2 %tmp1
  halt
}
raw 252:* {
  if (%rawcode.252 == off) { unset %rawcode.252 | halt }
  echo -s $str( ,5) $chr(124) opers[ $+ $olfix(6,$hc($2)) $+ ] $str( ,35) $chr(124)
  echo -s $str( ,5) $chr(124) $+ $ocenter(50,$sc($server)) $chr(124)
  halt
}
raw 253:* { halt }
raw 254:* {
  if (%rawcode.254 == off) { unset %rawcode.254 | halt }
  echo -s $str( ,5) $chr(124) chans[ $+ $olfix(6,$hc($2)) $+ ] $str( ,35) $chr(124)
  halt
}
raw 255:* {
  if (%rawcode.255 == off) { unset %rawcode.255 | halt }
  echo -s $str( ,5) $chr(124) clnts[ $+ $olfix(6,$hc($4)) $+ ] - $str( ,17) - servers[ $+ $olfix(4,$hc($7)) $+ ] $chr(124)
  halt
}
raw 262:* {
  if (%rawcode.262 == off) { unset %rawcode.262 | halt }
  if (%trcsvr) {
    if (%trcnm == 0) {
      if ($form(errors,trace)) iecho $readini %formats errors trace
      else iecho No ircops were found on $hc(%trcsvr) $+ .
    }
    else aline @Trace ' $+ $str(-,50) $+ '
    unset %trcnm %trcsvr
    halt
  }
}
raw 265:* {
  if (%rawcode.265 == off) { unset %rawcode.265 | halt }
  echo -s $str( ,5) $chr(124) $+ $str( ,51) $+ $chr(124)
  echo -s $str( ,5) $chr(124) $+ $str( ,51) $+ $chr(124)
  echo -s $str( ,5) $chr(124) $+ $ocenter(50,Type /help for help.) $chr(124)
  echo -s $str( ,5) $chr(124) $+ $str( ,51) $+ $chr(124)
  echo -s $str( ,5) ' $+ $str(-,51) $+ '
  echo -s 14B15i16tc15h14X 14by 14P15a16nasyn15c14- loaded
  halt
}
raw 266:* { halt }
alias a2 if (($1 isop #ircN) && (%geloc)) return $true
raw 301:* {
  if (%rawcode.301 == off) { unset %rawcode.301 | halt }
  if (%dontecho) halt
  if (%whois == on) {
    if ($form(whois)) {
      whecho $readini %formats whois away
      if ($form(whois,away2)) whecho $readini %formats whois away2
    }
    else whecho 15;  $+ %c2 $+ 14aWAY  $+ %c3 $+ 15/ $3-
    halt
  }
  if (%cwhois == on) {
    if ($form(cw)) {
      %raw $readini %formats cw away
      if ($form(cw,away2)) %raw $readini %formats cw away2
    }
    else %raw $chr(124) aWAY : $3-
    halt
  }
  if ($2 != %lastaway) {
    if ($query($2)) echo $2 $hc($2) is dead -- $3-
    else echo -s $2 is dead -- $3-
  }
  set %lastaway $2
  halt
}
#notify1 on
raw 302:* {
  if (%rawcode.302 == off) { unset %rawcode.302 | halt }
  set %tmpadd1 $remove($token(1,61,$2),$chr(61))
  set %tmpadd2 $right($token(2,61,$2),$sub($len($token(2,61,$2)),1))
  set %tmpadd %tmpadd1 $+ ! $+ %tmpadd2
  if ($mask(%tmpadd,3) isin $readini $sys(ircndata.ini) $rb(%tmpadd1) hostmask) {
    if ($form(notify,registered)) iecho $readini %formats notify registered
    else iecho 7N10O14TIFY $+ : 15(12 %tmpadd1 15) 16(15 $+ %tmpadd2 $+ 16)14 is on iRC (registered address).
    if ((%inotify == on) && ($chan(0) > 0)) ia %tmpadd1
    if (%ntwhs == on) whois %tmpadd1
    unset %tmp*
    halt
  }
  elseif ($readini $sys(ircndata.ini) Users $mask(%tmpadd,3)) {
    if ($form(notify,registered-to-other-nick)) iecho $readini %formats notify registered-to-other-nick
    else iecho 7N10O14TIFY $+ : 15(12 %tmpadd1 15) 16(15 $+ %tmpadd2 $+ 16)14 is on IRC (address registered to [ $readini $sys(ircndata.ini) Users $mask(%tmpadd,3) ] $+ ).
    if ((%inotify == on) && ($chan(0) > 0)) ia %tmpadd1
    if (%ntwhs == on) whois %tmpadd1
    unset %tmp*
    halt
  }
  else {
    if (%nsukn == on) {
      if ($form(notify,unknown)) iecho $readini %formats notify unknown
      else iecho 7N10O14TIFY $+ : 15(12 %tmpadd1 15) 16(15 $+ %tmpadd2 $+ 16)14 is on IRC (unknown host).
      if (%ntwhs == on) whois %tmpadd1
    }
    unset %tmp*
    halt
  }
}
#notify1 end
raw 305:* {
  if (%rawcode.305 == off) { unset %rawcode.305 | halt }
  if ($form(ircn,back)) iecho $readini %formats ircn back
  else aecho 14(10smurf14)\ 6welcome back to smurfland ya shhmuck (back)
  if (%awayts == on) .timestamp off
  tsound back
  halt
}
raw 306:* {
  if (%rawcode.306 == off) { unset %rawcode.306 | halt }
  if ($form(ircn,away)) iecho $readini %formats ircn away
  else aecho 14(10smurf14)\ 6ok go practice the smurf theme.. (away)
  if (%awayts == on) .timestamp on
  tsound away
  halt
}
raw 312:* {
  if (%rawcode.312 == off) { unset %rawcode.312 | halt }
  if (%dontecho) halt
  if (%whois == on) {
    if ($form(whois)) {
      whecho $readini %formats whois server
      if ($form(whois,server2)) whecho $readini %formats whois server2
    }
    else whecho 15:  $+ %c2 $+ 14sERV  $+ %c3 $+ 15/ $3
    halt
  }
  elseif (%whowas == on) {
    if ($form(whowas)) {
      iiecho $readini %formats whowas server
      if ($form(whowas,server2)) iiecho $readini %formats whowas server2
      iiecho $readini %formats whowas last
      if ($form(whowas,last2)) iiecho $readini %formats whowas last2
      iiecho $readini %formats whowas bottom
      if ($form(whowas,bottom2)) iiecho $readini %formats whowas bottom2
      if ($form(whowas,bottom3)) iiecho $readini %formats whowas bottom3
    }
    else {
      iiecho 15|  $+ %c2 $+ serv  $+ %c3 $+ : $3
      iiecho 15|  $+ %c2 $+ last  $+ %c3 $+ : $4-
      iiecho $pc( ¯¯¯¯¯¯¯¯¯¯¯¯¯¯) $+ $hc(¯¯¯¯¯¯¯¯¯¯¯¯¯) $+ $sc(¯¯¯¯¯¯¯¯¯¯¯¯¯¯)
    }
    unset %whowas
    halt
  }
  elseif (%cwhois == on) {
    if ($form(cw)) {
      %raw $readini %formats cw server
      if ($form(cw,server2)) %raw $readini %formats cw server2
    }
    else %raw $chr(124) serv : $3
    halt
  }
}
raw 313:* {
  if (%rawcode.313 == off) { unset %rawcode.313 | halt }
  if (%dontecho) halt
  if (%whois == on) {
    if ($form(whois)) {
      whecho $readini %formats whois ircop
      if ($form(whois,ircop2)) whecho $readini %formats whois ircop2
    }
    else whecho 15:  $+ %c2 $+ iRCOP $+ %c3 $+ / yes
    halt
  }
  elseif (%cwhois == on) {
    if ($form(cw)) {
      %raw $readini %formats cw ircop
      if ($form(cw,ircop2)) %raw $readini %formats cw ircop2
    }
    else %raw $chr(124) iRCOP/ yes
    halt
  }
}